@@ -12,11 +12,11 @@ PDF::Imposition - Perl module to manage the PDF imposition
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 
 =head1 SYNOPSIS
@@ -145,7 +145,7 @@ E.g.
 
 sub available_schemas {
     return qw/2up 2down 2side 2x4x2 1x4x2cutfoldbind
-              4up/;
+              4up 1repeat2top 1repeat2side 1repeat4/;
 }
 
 =head1 AUTHOR
@@ -158,6 +158,8 @@ Please report any bugs or feature requests to the author's email. If
 you find a bug, please provide a minimal example file which reproduces
 the problem (so I can add it to the test suite).
 
+Or, at your discretion, feel free to use the CPAN's RT.
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -166,7 +168,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 REPOSITORY
 
-L<https://gitorious.org/perl-pdf-imposition>
+L<https://github.com/melmothx/pdf-imposition-perl>
 
 =head1 SEE ALSO
 
